aboutsummaryrefslogtreecommitdiffstats
path: root/tun/wintun/setupapi/types_windows.go
diff options
context:
space:
mode:
authorSimon Rozman <simon@rozman.si>2019-02-07 22:09:18 +0100
committerSimon Rozman <simon@rozman.si>2019-02-07 22:43:02 +0100
commit6d2729dcccc7d02a2578ee28580b351769868b03 (patch)
treeff03127e8e7ae4d9cab7f06522b5fdf8055d9be6 /tun/wintun/setupapi/types_windows.go
parentwintun: Detect if a foreign interface with the same name exists (diff)
downloadwireguard-go-6d2729dcccc7d02a2578ee28580b351769868b03.tar.xz
wireguard-go-6d2729dcccc7d02a2578ee28580b351769868b03.zip
setupapi: Rename SP_DEVINFO_DATA to DevInfoData
Signed-off-by: Simon Rozman <simon@rozman.si>
Diffstat (limited to 'tun/wintun/setupapi/types_windows.go')
-rw-r--r--tun/wintun/setupapi/types_windows.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/tun/wintun/setupapi/types_windows.go b/tun/wintun/setupapi/types_windows.go
index c4aeff9..23bee25 100644
--- a/tun/wintun/setupapi/types_windows.go
+++ b/tun/wintun/setupapi/types_windows.go
@@ -49,9 +49,9 @@ type HSPFILEQ uintptr
// DevInfo holds reference to device information set
type DevInfo windows.Handle
-// SP_DEVINFO_DATA is a device information structure (references a device instance that is a member of a device information set)
-type SP_DEVINFO_DATA struct {
- Size uint32
+// DevInfoData is a device information structure (references a device instance that is a member of a device information set)
+type DevInfoData struct {
+ size uint32
ClassGUID windows.GUID
DevInst uint32 // DEVINST handle
_ uintptr